#!/bin/ksh
################################################################################
####  UNIX Script Documentation Block
#                      .                                             .
# Script name:         eta_prdgen.sh
# Script description:  Run 00-12 h eta product generator jobs
#
# Author:        Eric Rogers       Org: NP22         Date: 1999-06-23
#
# Abstract: This script runs the 00-12 h Eta PRDGEN jobs
#
# Script history log:
# 1999-06-23  Eric Rogers
# 1999-08-25  Brent Gordon  Pulled the PRDGEN here file out of the post
#                           jobs into this script.
#

set -x

export fhr=$1
export PS4='PRDGEN${fhr}_T$SECONDS + '

cp $PARMhiresw/hiresw_master.${NEST}.ctl master${fhr}.ctl

cp $COMIN/${RUN}.${cycle}.egdawp${fhr}.tm00 EGDAWP${fhr}.tm00
cat >input${fhr}.prd <<EOF5
$DATA/EGDAWP${fhr}.tm00
EOF5

export pgm=hiresw_prdgen;. prep_step
export XLFUNIT_10="master${fhr}.ctl"
export XLFUNIT_21="$FIXhiresw/hiresw_wgt_${NEST}_reg"
export XLFUNIT_41="$PARMeta/eta_kwbx.tbl"
export XLFUNIT_42="$PARMeta/eta_time.tbl"
export XLFUNIT_43="$PARMeta/eta_parm.tbl"
export XLFUNIT_44="$PARMeta/eta_grid.tbl"
export XLFUNIT_45="$PARMeta/eta_levl.tbl"
$EXEChiresw/hiresw_prdgen < input${fhr}.prd > prdgen.out${fhr}
export err=$?;err_chk

if test $SENDCOM = 'YES'
then
    $utilexec/grbindex meso.AWPREG${fhr}.tm00 AWPREGi${fhr}.tm00
    cp AWPREGi${fhr}.tm00 $COMOUT/${RUN}.${cycle}.awpregi${fhr}.tm00
    cp meso.AWPREG${fhr}.tm00 $COMOUT/${RUN}.${cycle}.awpreg${fhr}.tm00

    if test $SENDDBN = 'YES'
    then
     $DBNROOT/bin/dbn_alert MODEL ERL_${DBN_NEST}_AWIP $job $COMOUT/${RUN}.${cycle}.awpreg${fhr}.tm00
     $DBNROOT/bin/dbn_alert MODEL ERL_${DBN_NEST}_AWIPI $job $COMOUT/${RUN}.${cycle}.awpregi${fhr}.tm00
    fi
fi

echo EXITING $0
exit
